"""
Senshi (戦士) — AI-Powered Security Scanner

SAST + DAST security scanning powered by LLMs for bug bounty hunters.
"""

__version__ = "0.5.3"
__author__ = "Manthan Ghasadiya"
__description__ = "AI-powered SAST + DAST security scanner for bug bounty hunters"
