import sqlite3

def get_user(id):
    db = sqlite3.connect('test.db')
    cursor = db.cursor()
    # SQL Injection vulnerability
    query = "SELECT * FROM users WHERE id = " + id
    cursor.execute(query)
    return cursor.fetchone()

if __name__ == "__main__":
    print(get_user("1"))
